@@ -5,7 +5,7 @@
  *                                                                   
  *        Copyright (C) 1999, 2000, 2001, 2002, 2003 
  *                      2004, 2005, 2006, 2007, 2008
- *                      2009 Henrik Sandklef      
+ *                      2009, 2010 Henrik Sandklef      
  *                                                                   
  * This program is free software; you can redistribute it and/or     
  * modify it under the terms of the GNU General Public License       
@@ -280,12 +280,12 @@ xnee_record_handle_event_printer(xnee_data * xd,
     case ReparentNotify:
       new_window_pos = xnee_get_new_window_pos(xd);
       
-      if (new_window_pos!=0)
+      if (xnee_is_forced_reparent_recording(xd))
 	{
 	  fprintf (out,"0,%u,0,0,0,0,0,%lu\n", 
 		   event_type,
 		   xrecintd->server_time );
-	}
+	} 
       XGetWindowAttributes(xd->grab, 
 			   xrec_data->event.u.reparent.window,
 			   &window_attributes_return);
@@ -651,6 +651,7 @@ void
 xnee_record_init (xnee_data *xd) 
 {
   int i=0;
+
   XNEE_DEBUG ( (stderr ," --> xnee_record_init()  \n"  ));
   xd->xnee_info.first_last      = False  ; /* Intercept all MotionNotify, else only first and last */
 
@@ -679,7 +680,6 @@ xnee_record_init (xnee_data *xd)
   xd->xnee_info.replayed_events = 0      ;
   xd->xnee_info.interrupt       = 0;
 
-
   for ( i=0 ; i< XNEE_NR_OF_TYPES ; i++) 
     {
       xd->xnee_info.data_ranges[i] = 0 ;       /* Count how many data specified */
@@ -795,45 +795,6 @@ xnee_has_record_extension(xnee_data *xd)
 }
 
 
-static int 
-xnee_record_from_data_display(xnee_data *xd)
-{
-  int ret_val = 0;
-
-  printf ("X info:   %s %d %d %d\n",
-	  xd->x_vendor_name, 
-	  xd->x_version_major, 
-	  xd->x_version_minor, 
-	  xd->x_version_minor_sub);
-
-  if (xd != NULL)
-    {
-      
-  if ( (xd->x_vendor_name != NULL ) && 
-       (strstr(xd->x_vendor_name, "X.Org") ))
-    {
-	  if ( ( xd->x_version_major == 1 ) &&
-	       ( xd->x_version_minor >= 4 ) )
-	    {
-	      ret_val = 1;
-	    }
-	}
-      else if (strstr(xd->x_vendor_name, "Sun Microsystems") )
-	{
-	  
-	  if ( ( xd->x_version_major == 1 ) &&
-	       ( xd->x_version_minor >= 3 ) )
-	    {
-	      ret_val = 1;
-	    }
-	}
-
-    }
-
-  printf ("RET: %d\n", ret_val);
-  return ret_val;
-}
-
 
 
 
@@ -875,91 +836,20 @@ xnee_setup_recording(xnee_data *xd)
       xd->record_setup->xids[0] = XRecordFutureClients; 
     }
 
-
-  if ( xnee_record_from_data_display(xd))
-    {
-      /*
-       * From X.org 1.6.0 to ????
-       * 
-       *   there seem to be something strange about 
-       *   the XRecordCreateContext call
-       *   which causes the XRecordEnableContextAsync 
-       *   to fail ... ugly fix, but it works
-       *
-       */
-      fprintf(stderr, "Workaround: Creating context on data display instead of control \n");
-      fprintf(stderr, "            You can ignore this message\n");
-      context_display = xd->data ;
-    }
-  else
-    {
-      context_display = xd->control ;
-    }
+  context_display = xnee_get_display_for_recordcontext(xd);
 
   xd->record_setup->rContext = 
     XRecordCreateContext(context_display, 
 			 xd->record_setup->data_flags, 
 			 xd->record_setup->xids,1, 
-			 xd->record_setup->range_array, nr_of_ranges);
-  XFlush(context_display);
+			 xd->record_setup->range_array, 
+			 nr_of_ranges);
 
   XFlush(xd->control);
   XFlush(xd->data);
   XSync(xd->control, True);
   XSync(xd->data, True);
 
-  /*  printf("%d <=== XRecordCreateContext(%d,%d, %d,%d, %d,%d)\n",
-	 xd->record_setup->rContext,
-	 xd->control, 
-	 xd->record_setup->data_flags, 
-	 xd->record_setup->xids[0],1, 
-	 xd->record_setup->range_array, nr_of_ranges);
-  
-    if(!XRecordGetContext(xd->control, xd->record_setup->rContext, (XRecordState **) &xd->record_setup->rState))
-    {
-    xnee_print_error ("\n Couldn't get the context information for Display %d\n", (int) xd->control) ;
-    exit(1);
-    }
-    printf (" enabled:  %d\n", xd->record_setup->rState->enabled);
-    printf (" datum:    %d\n", xd->record_setup->rState->datum_flags);
-    printf (" nclients: %d\n", xd->record_setup->rState->nclients);
-
-    exit(0);
-  */
-    /*
-      XRecordRegisterClients   (xd->control,
-			    xd->record_setup->rContext,
-			    xd->record_setup->data_flags, 
-			    xids,1,
-			    xd->record_setup->range_array,nr_of_ranges);    
-  xd->record_setup->xids[0] = xnee_client_id (xd->control);
-  xd->record_setup->xids[1] = xnee_client_id (xd->data);
-    */
-  /* 
-   *Remove our clients displays from recording ...
-   */
-  /*
-    XRecordUnregisterClients( xd->control, 
-    xd->record_setup->rContext,
-    xd->record_setup->xids,2);
-    
-    
-    if(!XRecordGetContext(xd->control, xd->record_setup->rContext, (XRecordState **) xd->record_setup->rState))
-    {
-    xnee_print_error ("\n Couldn't get the context information for Display %d\n", (int) xd->control) ;
-    exit(1);
-    }
-  */
-  /*
-    XRecordFreeState(xd->record_setup->rState); 
-    xd->record_setup->rState=NULL; 
-  */
-  
-/*   xnee_verbose((xd, "\t  GetContext      0x%lx (%d clients intercepted))\n",  */
-/* 		xd->record_setup->rContext,  */
-/* 		(int) ( (xd->record_setup->rState) - (xd->record_setup->nclients) )));    */
-  
-  
   xnee_verbose((xd, "<---xnee_setup_recording\n"));
   XNEE_DEBUG ( (stderr ," <-- xnee_setup_recording()  \n"  ));
   return (0);
@@ -989,29 +879,26 @@ xnee_unsetup_recording(xnee_data *xd)
        return XNEE_OK; 
      }
 
-  if ( xnee_record_from_data_display(xd))
-    {
-      fprintf(stderr, "Workaround: Disabling context on data display instead of control \n");
-      fprintf(stderr, "            You can ignore this message\n");
-      context_display = xd->data ;
-    }
-  else
-    {
-      context_display = xd->control ;
-    }
+  context_display = xnee_get_display_for_recordcontext(xd);
+
   xnee_verbose((xd, "---> xnee_unsetup_recording\n"));
 
+      printf ("Close context** %u %u   context:%u *** \n",
+	      xd,
+	      xd->record_setup,
+	      xd->record_setup->rContext); fflush(stdout);
+
   if (xd->record_setup->rContext != 0)
     {
       xnee_verbose((xd, "---  disabling context %d on %d \n", 
 		    (int)xd->record_setup->rContext, context_display));
-  
-      (void)XRecordDisableContext(xd->control, xd->record_setup->rContext);
 
-      xnee_verbose((xd, "---  freeing context \n"));
-      (void)XRecordFreeContext(xd->control, xd->record_setup->rContext);
+      (void)XRecordDisableContext(xd->control, xd->record_setup->rContext); 
 
-      xd->record_setup->rContext = 0;
+      (void)XRecordFreeContext(xd->control, 
+			       xd->record_setup->rContext);
+
+      xd->record_setup->rContext = NULL;
     }
 
 
@@ -1046,25 +933,8 @@ xnee_record_loop(xnee_data *xd)
    
    xnee_verbose((xd, " ---> xnee_record_loop()\n"));
   
-  if ( xnee_record_from_data_display(xd))
-    {
-      /*
-       * From X.org 1.6.0 to ????
-       * 
-       *   there seem to be something strange about 
-       *   the XRecordCreateContext call
-       *   which causes the XRecordEnableContextAsync 
-       *   to fail ... ugly fix, but it works
-       *
-       */
-      fprintf(stderr, "Workaround: Creating context on data display instead of control \n");
-      fprintf(stderr, "            You can ignore this message\n");
-      context_display = xd->data ;
-    }
-  else
-    {
-      context_display = xd->control ;
-    }
+
+  context_display = xnee_get_display_for_recordcontext(xd);
 
    /* 
     * In case the key pressed to invoke Xnee is not released
@@ -1128,48 +998,8 @@ xnee_record_async(xnee_data *xd)
     }
 
 
+  context_display = xnee_get_display_for_recordcontext(xd);
   
-  if ( xnee_record_from_data_display(xd))
-    {
-      /*
-       * From X.org 1.6.0 to ????
-       * 
-       *   there seem to be something strange about 
-       *   the XRecordCreateContext call
-       *   which causes the XRecordEnableContextAsync 
-       *   to fail ... ugly fix, but it works
-       *
-       */
-      fprintf(stderr, "Workaround: Creating context on data display instead of control \n");
-      fprintf(stderr, "            You can ignore this message\n");
-      context_display = xd->data ;
-    }
-  else
-    {
-      context_display = xd->control ;
-    }
-
-
-
-  if ( xnee_record_from_data_display(xd))
-    {
-      /*
-       * From X.org 1.6.0 to ????
-       * 
-       *   there seem to be something strange about 
-       *   the XRecordCreateContext call
-       *   which causes the XRecordEnableContextAsync 
-       *   to fail ... ugly fix, but it works
-       *
-       */
-      fprintf(stderr, "Workaround: Creating context on data display instead of control \n");
-      fprintf(stderr, "            You can ignore this message\n");
-      context_display = xd->data ;
-    }
-  else
-    {
-      context_display = xd->control ;
-    }
 
   xnee_verbose((xd, " --- xnee_record_async() enable context\n"));
 
@@ -1251,10 +1081,6 @@ xnee_record_async(xnee_data *xd)
     }
 
 
-/*   XRecordDisableContext(xd->control,  */
-/* 			xd->record_setup->rContext); */
-/*   XRecordFreeContext(xd->control,  */
-/* 			xd->record_setup->rContext); */
 
   if (ret == XNEE_OK)
     {
