@@ -5,7 +5,7 @@
  *                                                                   
  *        Copyright (C) 1999, 2000, 2001, 2002, 2003,
  *                      2004, 2005, 2006, 2007, 2008,
- *                      2009  Henrik Sandklef
+ *                      2009, 2010  Henrik Sandklef
  *                                                                   
  * This program is free software; you can redistribute it and/or     
  * modify it under the terms of the GNU General Public License       
@@ -625,6 +625,16 @@ static xnee_option_t xnee_options_impl[] =
       XNEE_OPTION_VISIBLE
     },
 
+    {
+      XNEE_FORCE_REPARENT_RECORD,
+      "force-reparent-recording",
+      "frr",
+      NULL,
+      "Force explicit recording of ReparentNotify event",
+      XNEE_GENERAL_OPTION,
+      XNEE_OPTION_VISIBLE
+    },
+
 
     {
       XNEE_LAST_OPTION,
@@ -907,10 +917,9 @@ xnee_key2string(xnee_data      *xd,
 
   id = xnee_key2id(xd, options, key);
 
-  xnee_verbose((xd, "Looking for %d ===> %d  '%s'\n",
+  xnee_verbose((xd, "Looking for %d ===> %d \n",
 		key, 
-		id, 
-		EMPTY_IF_NULL( options[id].option)));
+		id));
 
   if ( id == XNEE_OPTION_NOT_FOUND )
     {
@@ -1485,6 +1494,13 @@ xnee_parse_option_impl(xnee_data *xd, char **opt_and_args, int *args_used, int s
       break;
 
 
+    case XNEE_FORCE_REPARENT_RECORD:
+      verbose_option("XNEE_FORCE_REPARENT_RECORD");
+      ret = xnee_set_forced_reparent_recording (xd); 
+      *args_used = 0;
+      break;
+
+
 
 
 
@@ -1556,5 +1572,7 @@ xnee_parse_option_impl(xnee_data *xd, char **opt_and_args, int *args_used, int s
       break;
     }
 
+
+
   return ret;
 }
