@@ -4,7 +4,7 @@
  * Xnee enables recording and replaying of X protocol data           
  *                                                                   
  *        Copyright (C) 1999, 2000, 2001, 2002, 2003 
- *                      2009 Henrik Sandklef                    
+ *                      2009, 2010 Henrik Sandklef                    
  *                                                                   
  * This program is free software; you can redistribute it and/or     
  * modify it under the terms of the GNU General Public License       
@@ -104,7 +104,7 @@ xnee_get_max_range (xnee_data *xd)
  * xnee_close_down                                            *
  *                                                            *
  *                                                            *
- **************************************************************/
+**************************************************************/
 void 
 xnee_close_down(xnee_data* xd) 
 {
@@ -152,6 +152,7 @@ xnee_close_down(xnee_data* xd)
   xnee_verbose((xd, "Freeing modifier mapping memory %d ", (int)xd->map));
   XFreeModifiermap(xd->map);
 
+
   xnee_verbose((xd, "Closing displays on host "));
   if ( xd->display==NULL ) 
     {
@@ -165,6 +166,9 @@ xnee_close_down(xnee_data* xd)
       xnee_free(xd->display);
       xd->display=NULL;
     }
+  /* HESA HESA HESA */
+  if (0==1)
+    {
 
   if ( xd->control!=NULL)  
     {
@@ -177,26 +181,42 @@ xnee_close_down(xnee_data* xd)
   if ( xd->fake!=NULL)  
     {
       XNEE_DEBUG ( (stderr ," --> xnee_close_down() at 0.3 \n"  ));
-      xnee_verbose((xd, "Closing displays control=%d \n", (int) xd->fake));
+      xnee_verbose((xd, "Closing displays fake=%d \n", (int) xd->fake));
       XNEE_DEBUG ( (stderr ," --> xnee_close_down() at 0.3.1 \n"  ));
       XCloseDisplay ( xd->fake );
     }
+ 
+    }
 
-  XNEE_DEBUG ( (stderr ," --> xnee_close_down() at 0.4 \n"  )); 
+ XNEE_DEBUG ( (stderr ," --> xnee_close_down() at 0.4 \n"  )); 
   if ( xd->data!=NULL)  
     {
 /*       printf ("close data in %s   ---> %d\n", __func__, xd->data); */
       xnee_verbose((xd, "Closing displays data=%d \n", (int) xd->data));
+
+      
+      xnee_verbose((xd, "Closing displays data=%d  pending:%d\n", (int) xd->data, XPending(xd->data)));
+
+      XFlush(xd->data);
+      xnee_verbose((xd, "Closing displays data=%d  flushed\n", (int) xd->data));
+      usleep(1000*100);
+      xnee_verbose((xd, "Closing displays data=%d slept\n", (int) xd->data));
+
+      /* 
       XCloseDisplay ( xd->data );
+      */
     }
   
   XNEE_DEBUG ( (stderr ," --> xnee_close_down() at 0.41 \n"  )); 
   if ( xd->grab!=NULL)  
     {
-      xnee_verbose((xd, "Closing displays data=%d \n", (int) xd->grab));
+      xnee_verbose((xd, "Closing displays grab=%d \n", (int) xd->grab));
+      XFlush(xd->grab);
+      usleep(1000*1000);
       XCloseDisplay ( xd->grab );
     }
   
+
   XNEE_DEBUG ( (stderr ," --> xnee_close_down() at 0.5 \n"  ));
 
   xnee_verbose((xd, "closing fds\n"));
@@ -225,7 +245,8 @@ xnee_close_down(xnee_data* xd)
   ret = xnee_free_file (xd, xd->out_name,  xd->out_file);
   xd->out_file=NULL;
 
-  ret = xnee_free_xnee_data(xd);
+   ret = xnee_free_xnee_data(xd); 
+
   xd=NULL;
 }
 
@@ -356,6 +377,9 @@ xnee_init(xnee_data* xd)
       xnee_init_names();
   */
 
+
+  xd->forced_reparent_recording = 0;
+
   for (i=0;i<XNEE_NR_OF_TYPES;i++)
     {
       xd->xnee_info.data_ranges[i]=0;
